@@ -1,6 +1,6 @@
 /*
  SPDX-License-Identifier: GPL-3.0-or-later
- myGPIOd (c) 2020-2024 Juergen Mang <mail@jcgames.de>
+ myGPIOd (c) 2020-2025 Juergen Mang <mail@jcgames.de>
  https://github.com/jcorporation/myGPIOd
 */
 
@@ -25,7 +25,7 @@ enum mygpiod_actions {
     #endif
     #ifdef MYGPIOD_ENABLE_ACTION_HTTP
         MYGPIOD_ACTION_HTTP,      //!< Makes an HTTP call
-        MYGPIOD_ACTION_MYMPD,     //!< Executes a myMPD script
+        MYGPIOD_ACTION_MYMPD,     //!< Executes a myGPIOd script
     #endif
     #ifdef MYGPIOD_ENABLE_ACTION_LUA
         MYGPIOD_ACTION_LUA,       //!< Executes a lua function
